@@ -638,7 +638,7 @@ static void
 ggv_control_create_ui (GgvControl *control)
 {
 	GgvControlClass *klass;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf, *pixbuf_small;
 	gchar *pixbuf_xml;
 	int i;
 
@@ -647,23 +647,38 @@ ggv_control_create_ui (GgvControl *control)
 
 	klass = GGV_CONTROL_CLASS(G_OBJECT_GET_CLASS(control));
 
+	bonobo_ui_component_freeze(control->priv->uic, NULL);
 	bonobo_ui_util_set_ui(control->priv->uic, DATADIR, "ggv-control-ui.xml",
 						  "GGV", NULL);
+								 
+	control->priv->popup_uic = bonobo_control_get_popup_ui_component(BONOBO_CONTROL(control));
+	bonobo_ui_component_freeze(control->priv->popup_uic, NULL);
+	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-postscript-view-ui.xml", "GGV", NULL);
+	bonobo_ui_util_set_ui(control->priv->popup_uic, DATADIR, "ggv-control-ui.xml", "GGV", NULL);
+	
 	pixbuf = gdk_pixbuf_new_from_file(GNOMEICONDIR "/ggv/fitwidth.png", NULL);
 	if(pixbuf != NULL) {
 		pixbuf_xml = bonobo_ui_util_pixbuf_to_xml(pixbuf);
 		bonobo_ui_component_set_prop(control->priv->uic,
-									 "/commands/ZoomToFitWidth",
+									 "/Toolbar/GgvItems/GgvZoomItems/ZoomToFitWidth",
+									 "pixname", pixbuf_xml,
+									 NULL);
+		g_free(pixbuf_xml);
+		pixbuf_small = gdk_pixbuf_scale_simple(pixbuf, 18, 18, GDK_INTERP_TILES);
+		pixbuf_xml = bonobo_ui_util_pixbuf_to_xml(pixbuf_small);
+		bonobo_ui_component_set_prop(control->priv->uic,
+									 "/menu/View/Zoom Items Placeholder/Zoom/ZoomToFitWidth",
+									 "pixname", pixbuf_xml,
+									 NULL);
+		bonobo_ui_component_set_prop(control->priv->popup_uic,
+									 "/popups/button3/ZoomMenu/ZoomToFitWidth",
 									 "pixname", pixbuf_xml,
 									 NULL);
 		g_free(pixbuf_xml);
 		gdk_pixbuf_unref(pixbuf);
+		gdk_pixbuf_unref(pixbuf_small);
 	}
-								 
-	control->priv->popup_uic = bonobo_control_get_popup_ui_component(BONOBO_CONTROL(control));
-	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-postscript-view-ui.xml", "GGV", NULL);
-	bonobo_ui_util_set_ui(control->priv->popup_uic, DATADIR, "ggv-control-ui.xml", "GGV", NULL);
-	
+
 	for(i = 0; zoom_level_items[i].path; i++) {
 		bonobo_ui_component_add_listener(control->priv->uic,
 										 zoom_level_items[i].path + strlen("/commands/"),
@@ -722,6 +737,8 @@ ggv_control_create_ui (GgvControl *control)
 		control->priv->zoom_control = zoom_control;
 		control->priv->zoom_adj = zoom_adj;
 	}
+	bonobo_ui_component_thaw(control->priv->uic, NULL);
+	bonobo_ui_component_thaw(control->priv->popup_uic, NULL);
 }
 
 static void
