@@ -90,7 +90,7 @@ static GdkCursor *pan_cursor = NULL;
 static BonoboObjectClass *ggv_postscript_view_parent_class;
 
 static const gchar *orientation_paths[] = {
-	"/commands/OverrideOrientation",
+	"/commands/OrientationDocument",
 	"/commands/OrientationPortrait",
 	"/commands/OrientationLandscape",
 	"/commands/OrientationUpsideDown",
@@ -99,7 +99,7 @@ static const gchar *orientation_paths[] = {
 };
 
 static const gchar *size_paths[] = {
-	"/commands/OverrideSize",
+	"/commands/PaperSizeDoc",
 	"/commands/PaperSizeBBox",
 	"/commands/PaperSizeLetter",
 	"/commands/PaperSizeTabloid",
@@ -107,6 +107,9 @@ static const gchar *size_paths[] = {
 	"/commands/PaperSizeLegal",
 	"/commands/PaperSizeStatement",
 	"/commands/PaperSizeExecutive",
+	"/commands/PaperSizeA0",
+	"/commands/PaperSizeA1",
+	"/commands/PaperSizeA2",
 	"/commands/PaperSizeA3",
 	"/commands/PaperSizeA4",
 	"/commands/PaperSizeA5",
@@ -577,9 +580,9 @@ listener_Orientation_cb (BonoboUIComponent *uic, const char *path,
 						 Bonobo_UIComponent_EventType type, const char *state,
 						 gpointer user_data)
 {
-	BonoboArg *arg;
 	GgvPostScriptView *ps_view;
-	GNOME_GGV_Orientation orientation;
+	GtkGSOrientation orientation;
+	GtkGS *gs;
 
 	g_return_if_fail(user_data != NULL);
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW (user_data));
@@ -591,84 +594,74 @@ listener_Orientation_cb (BonoboUIComponent *uic, const char *path,
 		return;
 
 	ps_view = GGV_POSTSCRIPT_VIEW(user_data);
+	gs = GTK_GS(ps_view->priv->gs);
 
-	if(!strcmp(path, "OrientationPortrait"))
-		orientation = GNOME_GGV_ORIENTATION_PORTRAIT;
-	else if(!strcmp(path, "OrientationLandscape"))
-		orientation = GNOME_GGV_ORIENTATION_LANDSCAPE;
-	else if(!strcmp(path, "OrientationUpsideDown"))
-		orientation = GNOME_GGV_ORIENTATION_UPSIDEDOWN;
-	else if(!strcmp(path, "OrientationSeascape"))
-		orientation = GNOME_GGV_ORIENTATION_SEASCAPE;
+	if(!strcmp(path, "OrientationDocument")) {
+		if(gs->override_orientation == TRUE) {
+			gtk_gs_set_override_orientation(GTK_GS(ps_view->priv->gs), FALSE);
+			notify_orientation_change(ps_view);
+		}
+	}
 	else {
-		g_warning("Unknown orientation `%s'", path);
-		return;
+		if(!strcmp(path, "OrientationPortrait"))
+			orientation = GTK_GS_ORIENTATION_PORTRAIT;
+		else if(!strcmp(path, "OrientationLandscape"))
+			orientation = GTK_GS_ORIENTATION_LANDSCAPE;
+		else if(!strcmp(path, "OrientationUpsideDown"))
+			orientation = GTK_GS_ORIENTATION_UPSIDEDOWN;
+		else if(!strcmp(path, "OrientationSeascape"))
+			orientation = GTK_GS_ORIENTATION_SEASCAPE;
+		else {
+			g_warning("Unknown orientation `%s'", path);
+			return;
+		}
+		gtk_gs_set_default_orientation(GTK_GS(ps_view->priv->gs), orientation);
+		if(gs->override_orientation == FALSE) {
+			gtk_gs_set_override_orientation(GTK_GS(ps_view->priv->gs), TRUE);
+		}
+		notify_orientation_change(ps_view);		
 	}
-
-	arg = bonobo_arg_new(TC_GNOME_GGV_Orientation);
-	BONOBO_ARG_SET_GENERAL(arg, orientation, TC_GNOME_GGV_Orientation,
-						   GNOME_GGV_Orientation, NULL);
-
-	bonobo_pbclient_set_value(BONOBO_OBJREF(ps_view->priv->property_bag),
-							  "default_orientation", arg, NULL);
-
-	bonobo_arg_release(arg);
 }
 
 static void
-listener_Toggle_cb (BonoboUIComponent *uic, const char *path,
-					Bonobo_UIComponent_EventType type, const char *state,
-					gpointer user_data)
+sync_orientation_items(GgvPostScriptView *ps_view)
 {
-	BonoboArg *arg;
-	GgvPostScriptView *ps_view;
-	CORBA_boolean flag;
-	gchar *prop;
-	int i;
-
-	static gchar *properties[][2] = {
-		{ "OverrideOrientation", "override_orientation" },
-		{ "OverrideSize", "override_size" },
-		{ "RespectEOF", "respect_eof" },
-		{ "Antialiasing", "antialiasing" },
-		{ "WatchFile", "watch_file" },
-		{ NULL, NULL }
-	};
-
-	g_return_if_fail(user_data != NULL);
-	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW (user_data));
-
-	if(type != Bonobo_UIComponent_STATE_CHANGED)
-		return;
-
-	if(!state)
-		return;
+	gint i;
+	gboolean orient_state;
 	
-	ps_view = GGV_POSTSCRIPT_VIEW(user_data);
-
-	if(atoi(state))
-		flag = CORBA_TRUE;
-	else
-		flag = CORBA_FALSE;
-
-	prop = NULL;
-	for(i = 0; properties[i][0]; i++) {
-		if(!strcmp(path, properties[i][0])) {
-			prop = properties[i][1];
-			break;
-		}
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
+	for(i = 0; orientation_paths[i] != NULL; i++) {
+		if(i > 0)
+			orient_state = ((TRUE == GTK_GS(ps_view->priv->gs)->override_orientation) &&
+							(i - 1 == gtk_gs_get_default_orientation(GTK_GS(ps_view->priv->gs))));
+		else
+			orient_state = (FALSE == GTK_GS(ps_view->priv->gs)->override_orientation);
+		bonobo_ui_component_set_prop(ps_view->priv->uic, orientation_paths[i],
+									 "state", orient_state?"1":"0", NULL);
 	}
+	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
+}
 
-	g_assert(prop != NULL);
+static void
+sync_size_items(GgvPostScriptView *ps_view)
+{
+	gint i;
+	gboolean size_state;
+	const gchar **paths;
 
-	arg = bonobo_arg_new(TC_CORBA_boolean);
-	BONOBO_ARG_SET_GENERAL(arg, flag, TC_CORBA_boolean,
-						   CORBA_boolean, NULL);
+	paths = size_paths;
 
-	bonobo_pbclient_set_value(BONOBO_OBJREF(ps_view->priv->property_bag),
-							  prop, arg, NULL);
-
-	bonobo_arg_release(arg);
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
+	for(i = 0; paths[i] != NULL; i++) {
+		if(i > 0)
+			size_state = ((TRUE == GTK_GS(ps_view->priv->gs)->override_size) &&
+						  (i - 1 == gtk_gs_get_default_size(GTK_GS(ps_view->priv->gs))));
+		else
+			size_state = (FALSE == GTK_GS(ps_view->priv->gs)->override_size);
+		bonobo_ui_component_set_prop(ps_view->priv->uic, paths[i],
+									 "state", size_state?"1":"0", NULL);
+	}
+	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
 }
 
 static void
@@ -677,8 +670,8 @@ listener_Size_cb(BonoboUIComponent *uic, const char *path,
 				  gpointer user_data)
 {
 	GgvPostScriptView *ps_view;
-	GNOME_GGV_Size size;
-	BonoboArg *arg;
+	gint size;
+	GtkGS *gs;
 
 	g_return_if_fail(user_data != NULL);
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW(user_data));
@@ -690,17 +683,23 @@ listener_Size_cb(BonoboUIComponent *uic, const char *path,
 		return;
 
 	ps_view = GGV_POSTSCRIPT_VIEW(user_data);
+	gs = GTK_GS(ps_view->priv->gs);
 
-	size = CORBA_string_dup(path + strlen("PaperSize"));
-
-	arg = bonobo_arg_new(TC_GNOME_GGV_Size);
-	BONOBO_ARG_SET_GENERAL(arg, size, TC_GNOME_GGV_Size,
-						   GNOME_GGV_Size, NULL);
-
-	bonobo_pbclient_set_value(BONOBO_OBJREF(ps_view->priv->property_bag),
-							  "default_size", arg, NULL);
-
-	bonobo_arg_release(arg);
+	if(!strcmp(path, "PaperSizeDoc")) {
+		if(gs->override_size == TRUE) {
+			gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs), FALSE);
+			sync_size_items(ps_view);
+		}
+	}
+	else {
+		size = gtk_gs_get_size_index(path + strlen("PaperSize"),
+									 gtk_gs_defaults_get_paper_sizes());
+		gtk_gs_set_default_size(GTK_GS(ps_view->priv->gs), size);
+		if(gs->override_size == FALSE) {
+			gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs), TRUE);
+		}
+		sync_size_items(ps_view);
+	}
 }
 
 
@@ -973,49 +972,6 @@ verb_SettingsPreferences(BonoboUIComponent *uic, gpointer data, const char *cnam
 		ggv_raise_and_focus_widget(dlg);
 }
 
-static void
-sync_orientation_items(GgvPostScriptView *ps_view)
-{
-	gint i;
-	gboolean val, orient_state;
-
-	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
-	val = gtk_gs_get_override_orientation(GTK_GS(ps_view->priv->gs));
-	bonobo_ui_component_set_prop(ps_view->priv->uic, orientation_paths[0],
-								 "state", val?"1":"0", NULL);
-	for(i = 1; orientation_paths[i] != NULL; i++) {
-		bonobo_ui_component_set_prop(ps_view->priv->uic, orientation_paths[i],
-									 "sensitive", val?"1":"0", NULL);
-		orient_state = (i - 1 == gtk_gs_get_default_orientation(GTK_GS(ps_view->priv->gs)));
-		bonobo_ui_component_set_prop(ps_view->priv->uic, orientation_paths[i],
-									 "state", orient_state?"1":"0", NULL);
-	}
-	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
-}
-
-static void
-sync_size_items(GgvPostScriptView *ps_view)
-{
-	gint i;
-	gboolean val, size_state;
-	const gchar **paths;
-
-	paths = size_paths;
-
-	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
-	val = gtk_gs_get_override_size(GTK_GS(ps_view->priv->gs));
-	bonobo_ui_component_set_prop(ps_view->priv->uic, paths[0],
-								 "state", val?"1":"0", NULL);
-	for(i = 1; paths[i] != NULL; i++) {
-		bonobo_ui_component_set_prop(ps_view->priv->uic, paths[i],
-									 "sensitive", val?"1":"0", NULL);
-		size_state = i - 1 == gtk_gs_get_default_size(GTK_GS(ps_view->priv->gs));
-		bonobo_ui_component_set_prop(ps_view->priv->uic, paths[i],
-									 "state", size_state?"1":"0", NULL);
-	}
-	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
-}
-
 BonoboUIVerb ggv_postscript_view_verbs[] = {
 	BONOBO_UI_VERB("SettingsPreferences", verb_SettingsPreferences),
 	BONOBO_UI_VERB("FileSaveMarked", verb_FileSaveMarked),
@@ -1036,11 +992,11 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 	g_return_if_fail(ps_view != NULL);
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW(ps_view));
 
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	/* Set up the UI from an XML file. */
 	bonobo_ui_util_set_ui(ps_view->priv->uic, DATADIR,
 						  "ggv-postscript-view-ui.xml", 
 						  "GGV", NULL);
-	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/Sidebar",
 								 "placement", ggv_right_panel?"right":"left", NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/Sidebar",
@@ -1054,19 +1010,15 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 								   BONOBO_OBJREF(ps_view->priv->sidebar), NULL);
 #endif
 
-	for(i = 1; size_paths[i]; i++) 
+	for(i = 0; size_paths[i]; i++) 
 		bonobo_ui_component_add_listener(ps_view->priv->uic,
 										 size_paths[i] + strlen("/commands/"),
 										 listener_Size_cb, ps_view);
 
-	for(i = 1; orientation_paths[i]; i++) 
+	for(i = 0; orientation_paths[i]; i++) 
 		bonobo_ui_component_add_listener(ps_view->priv->uic,
 										 orientation_paths[i] + strlen("/commands/"),
 										 listener_Orientation_cb, ps_view);
-	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideSize",
-									 listener_Toggle_cb, ps_view);
-	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideOrientation",
-									 listener_Toggle_cb, ps_view);
 	set_file_items_sensitivity(ps_view,
 							   ggv_postscript_view_get_page_count(ps_view) > 0);
 	set_page_items_sensitivity(ps_view);
@@ -1335,18 +1287,15 @@ ggv_postscript_view_set_prop(BonoboPropertyBag *bag,
 
 		gtk_gs_set_default_orientation(GTK_GS(ps_view->priv->gs), orient);
 		notify_orientation_change(ps_view);
-		/*
 		sync_orientation_items(ps_view);
-		*/
-
 		break;
 	}
 	case PROP_OVERRIDE_ORIENTATION: {
-		 gtk_gs_set_override_orientation(GTK_GS(ps_view->priv->gs),
-										 *(CORBA_boolean *)arg->_value);
-		 notify_orientation_change(ps_view);
-		 sync_orientation_items(ps_view);
-		 break;
+		gtk_gs_set_override_orientation(GTK_GS(ps_view->priv->gs),
+										*(CORBA_boolean *)arg->_value);
+		notify_orientation_change(ps_view);
+		sync_orientation_items(ps_view);
+		break;
 	}
 	case PROP_DEFAULT_SIZE: {
 		gint size;
@@ -1357,18 +1306,16 @@ ggv_postscript_view_set_prop(BonoboPropertyBag *bag,
 		size_name = *(GNOME_GGV_Size *)arg->_value;
 
 		size = gtk_gs_get_size_index(size_name,
-									   gtk_gs_defaults_get_paper_sizes());
-
+									 gtk_gs_defaults_get_paper_sizes());
 		gtk_gs_set_default_size(GTK_GS(ps_view->priv->gs), size);
 		sync_size_items(ps_view);
-
 		break;
 	}
 	case PROP_OVERRIDE_SIZE: {
-		 gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs),
-								   *(CORBA_boolean *)arg->_value);
-		 sync_size_items(ps_view);
-		 break;
+		gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs),
+								 *(CORBA_boolean *)arg->_value);
+		sync_size_items(ps_view);
+		break;
 	}
 	case PROP_ANTIALIASING: {
 		 gtk_gs_set_override_size(GTK_GS(ps_view->priv->gs),
