@@ -17,6 +17,9 @@ GtkGSPaperSize ggv_paper_sizes[] = {
         {"Legal",        612, 1008,},
         {"Statement",	 396,  612,},
         {"Executive",	 540,  720,},
+        {"A0",           2380, 3368,},
+        {"A1",           1684, 2380,},
+        {"A2",           1190, 1684,},
         {"A3",		 842, 1190,},
         {"A4",		 595,  842,},
         {"A5",		 420,  595,},
@@ -58,15 +61,15 @@ const gint ggv_max_unit_labels =
     (sizeof(ggv_unit_labels) / sizeof(gchar *)) - 2;
 
 gfloat ggv_zoom_levels[] = {
-	1.0 / 10.0, 1.0 / 9.0, 1.0 / 8.0, 1.0 / 7.0, 1.0 / 6.0,
-	1.0 / 5.0, 1.0 / 4.0, 1.0 / 3.0, 1.0 / 2.0, 3.0 / 4.0, 1.0,
-        3.0 / 2.0, 2.0,	3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0
+	1.0 / 6.0, 1.0 / 5.0, 1.0 / 4.0, 1.0 / 3.0, 1.0 / 2.0, 3.0 / 4.0, 1.0,
+        3.0 / 2.0, 2.0,	3.0, 4.0, 5.0, 6.0
 };
 
 const gchar *ggv_zoom_level_names[] = {
-	"1:10", "1:9", "1:8", "1:7", "1:6", "1:5", "1:4", "1:3",
-	"1:2", "3:4", "1:1", "3:2", "2:1", "3:1", "4:1", "5:1", "6:1", "7:1",
-	"8:1", "9:1", "10:1"
+	"1:6", "1:5", "1:4", "1:3",
+	"1:2", "3:4", "1:1", "3:2",
+        "2:1", "3:1", "4:1", "5:1",
+        "6:1",
 };
 
 const gint ggv_max_zoom_levels =
