@@ -60,9 +60,7 @@
 #include "ps.h"
 #include "gsio.h"
 
-#ifdef BSD4_2
-#define memset(a,b,c) bzero(a,c)
-#endif
+#include <glib.h>
 
 /* length calculates string length at compile time */
 /* can only be used with character constants */
@@ -86,6 +84,21 @@ static int  blank();
 #endif
 
 
+static struct page *
+pages_new(struct page *pages, int current, int maxpages)
+{
+        struct page *oldpages = pages;
+        if(!oldpages)
+                pages = g_new0(struct page, maxpages);
+        else
+                pages = g_renew(struct page, oldpages, maxpages);
+        for(; current < maxpages; current++) {
+                memset(&(pages[current]), 0x00, current);
+                pages[current].orientation = GTK_GS_ORIENTATION_NONE;
+        }
+        return pages;
+}
+
 /*
  *	psscan -- scan the PostScript file for document structuring comments.
  *
@@ -258,6 +271,8 @@ struct document *psscan (FILE *file, int respect_eof)
      * parts of this or add a ^D at the beginning. */
     if (iscomment (line,"%!PS") || iscomment (line, "\004%!PS")) {
 	doc = g_new0 (struct document, 1);
+        doc->default_page_orientation = GTK_GS_ORIENTATION_NONE;
+        doc->orientation = GTK_GS_ORIENTATION_NONE;
 
         /* ignore possible leading ^D */
 	if (*line == '\004') {
@@ -289,6 +304,8 @@ struct document *psscan (FILE *file, int respect_eof)
 
       */
 	doc = g_new0 (struct document, 1);
+        doc->default_page_orientation = GTK_GS_ORIENTATION_NONE;
+        doc->orientation = GTK_GS_ORIENTATION_NONE;
 	return(doc);
     }
 
@@ -390,7 +407,7 @@ struct document *psscan (FILE *file, int respect_eof)
 			}
 		    case 1:
 			if (maxpages > 0)
-			    doc->pages = g_new0 (struct page, maxpages);
+			    doc->pages = pages_new(NULL, 0, maxpages);
 		}
 	    }
 	} else if (doc->numsizes == NONE &&
@@ -799,7 +816,8 @@ newpage:
     while (DSCcomment(line) && iscomment(line+2, "Page:")) {
 	if (maxpages == 0) {
 	    maxpages = 1;
-	    doc->pages = g_new0 (struct page, maxpages);
+	    doc->pages = pages_new(NULL, 0, maxpages);
+            
 	}
 	label = get_next_text(line+length("%%Page:"), &next_char);
 	if (sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
@@ -814,9 +832,8 @@ newpage:
 	nextpage++;
 	if (doc->numpages == maxpages) {
 	    maxpages++;
-	    doc->pages = g_renew (struct page, doc->pages, maxpages);
+	    doc->pages = pages_new (doc->pages, maxpages - 1, maxpages);
 	}
-	memset(&(doc->pages[doc->numpages]), 0, sizeof(struct page));
 	page_bb_set = NONE;
 	doc->pages[doc->numpages].label = label;
 	if (beginsection) {
